# Utils (WWW)

Utilities for accessing webpages

## Setup & Install

https://pypi.org/project/utils_www-nuuuwan/#history

```
pip install utils_www-nuuuwan
```

## Version History 

### 1.2.9 (NEXT VERSION)

### 1.2.8 (CURRENT VERSION)

* Make compatible with utils_base-nuuuwan===1.0.9

### 1.2.7 

* Base Version